==> qmmp-0.12.4.tar.bz2: qmmp-0.12.4/src/plugins/Effect/monotostereo/monotostereoplugin.h <==
/***************************************************************************
 *   Copyright (C) 2018 by Ilya Kotov                                      *
 *   forkotov02@ya.ru                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef MONOTOSTEREOPLUGIN_H
#define MONOTOSTEREOPLUGIN_H

#include <QMutex>
#include <qmmp/effect.h>

/**
    @author Ilya Kotov <forkotov02@ya.ru>
*/
class MonoToStereoPlugin : public Effect
{
public:
    MonoToStereoPlugin();

    virtual ~MonoToStereoPlugin();

    void applyEffect(Buffer *b);
    void configure(quint32 freq, ChannelMap map);

private:
    bool m_enabled;
    float *m_tmp;
    size_t m_size; //in samples

};

#endif

==> qmmp_1.3.1.orig.tar.bz2: qmmp-1.3.1/src/plugins/Effect/monotostereo/monotostereoplugin.h <==
/***************************************************************************
 *   Copyright (C) 2018-2019 by Ilya Kotov                                 *
 *   forkotov02@ya.ru                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef MONOTOSTEREOPLUGIN_H
#define MONOTOSTEREOPLUGIN_H

#include <QMutex>
#include <qmmp/effect.h>

/**
    @author Ilya Kotov <forkotov02@ya.ru>
*/
class MonoToStereoPlugin : public Effect
{
public:
    MonoToStereoPlugin();

    virtual ~MonoToStereoPlugin();

    void applyEffect(Buffer *b) override;
    void configure(quint32 freq, ChannelMap map) override;

private:
    bool m_enabled;
    float *m_tmp;
    size_t m_size; //in samples

};

#endif
